##  Automation 4: Relation Is Removed
Automation Configuration Parameter | Configuration
---|---
Trigger (When) |
  * Fact Sheet Type: IT component
  * Event: Relation Is Removed
  * Fact Sheet Relation: Consuming Applications


Conditions (If) | Configure optional conditions for the automation.
Actions (Then) | Run script: See the sample code provided below.


